==> tailwind-heropatterns-0.0.1.tgz: package/README.md <==
#   t a i l w i n d - h e r o p a t t e r n s 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 A d d   t h i s   p l u g i n   t o   y o u r   p r o j e c t : 
 
 
 
 ` ` ` b a s h 
 
 #   I n s t a l l   v i a   n p m 
 
 n p m   i n s t a l l   - - s a v e - d e v   t a i l w i n d - h e r o p a t t e r n s 
 
 
 
 #   o r   y a r n 
 
 y a r n   a d d   t a i l w i n d - h e r o p a t t e r n s   - - d e v 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 
 
 T h e   t a i l w i n d   h e r o p a t t e r n s   p l u g i n   e x p o s e s   s o m e   o p t i o n s   t o   c o n f i g u r e   t h e   g e n e r a t e d   c l a s s e s .   H e r e   i s   t h e   e x a m p l e   f o r   a d d i n g   i t   t o   y o u r   p r o j e c t   p l u g i n s 
 
 
 
 ` ` ` j s 
 
 r e q u i r e ( " t a i l w i n d - h e r o p a t t e r n s " ) ( { 
 
     / /   a s   p e r   t a i l w i n d   d o c s   y o u   c a n   p a s s   v a r i a n t s 
 
     v a r i a n t s :   [ ] , 
 
 
 
     / /   t h e   l i s t   o f   p a t t e r n s   y o u   w a n t   t o   g e n e r a t e   a   c l a s s   f o r 
 
     / /   t h e   n a m e s   m u s t   b e   i n   k e b a b - c a s e 
 
     / /   a n   e m p t y   a r r a y   w i l l   g e n e r a t e   a l l   8 7   p a t t e r n s 
 
     p a t t e r n s :   [ " p o l k a - d o t s " ,   " s i g n a l " ] , 
 
 
 
     / /   T h e   f o r e g r o u n d   c o l o r s   o f   t h e   p a t t e r n 
 
     c o l o r s :   { 
 
         d e f a u l t :   " 9 C 9 2 A C " , 
 
         " b l u e - d a r k " :   " 0 0 0 0 4 4 " 
 
     } , 
 
 
 
     / /   T h e   f o r e g r o u n d   o p a c i t y 
 
     o p a c i t i e s :   { 
 
         d e f a u l t :   " 0 . 4 " , 
 
         " 1 0 0 " :   " 1 . 0 " 
 
     } 
 
 } ) ; 
 
 ` ` ` 
 
 
 
 T h i s   c o n f i g u r a t i o n   w o u l d   c r e a t e   t h e   f o l l o w i n g   c l a s s e s : 
 
 
 
 ` ` ` c s s 
 
 . b g - h e r o - p o l k a - d o t s - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - p o l k a - d o t s - b l u e - d a r k - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l - b l u e - d a r k - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - p o l k a - d o t s   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - p o l k a - d o t s - b l u e - d a r k   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l - b l u e - d a r k   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 ` ` ` 
 
 
 
 A s   y o u   c a n   s e e   w h e n   y o u   u s e   t h e   ` d e f a u l t `   k e y   f o r   c o l o r s   o r   o p a c i t y   i t   i s   o m i t t e d   i n   t h e   c l a s s   n a m e . 
 
 
 
 S o   t h e   f o l l o w i n g   c o n f i g u r a t i o n : 
 
 
 
 ` ` ` j s 
 
 r e q u i r e ( " t a i l w i n d - h e r o p a t t e r n s " ) ( { 
 
     v a r i a n t s :   [ ] , 
 
     p a t t e r n s :   [ " p o l k a - d o t s " ,   " s i g n a l " ] , 
 
     c o l o r s :   { 
 
         d e f a u l t :   " 9 C 9 2 A C " 
 
     } , 
 
     o p a c i t i e s :   { 
 
         d e f a u l t :   " 0 . 4 " 
 
     } 
 
 } ) ; 
 
 ` ` ` 
 
 
 
 W i l l   g e n e r a t e   o n l y   t h e   f o l l o w i n g   c l a s s e s 
 
 
 
 ` ` ` c s s 
 
 . b g - h e r o - p o l k a - d o t s   { 
 
     / * * / 
 
 } 
 
 . b g - h e r o - s i g n a l   { 
 
     / * * / 
 
 } 
 
 ` ` ` 
 
 
 
 # #   D e f a u l t s 
 
 
 
 T h e   d e f a u l t   c o n f i g u r a t i o n   i s   t h e   f o l l o w i n g . 
 
 A n d   i t   w i l l   g e n e r a t e   a l l e   t h e   p a t t e r n s   w i t h   t h e   d e f a u l t   c o l o r   o f   [ h e r o p a t t e r n s . c o m ] ( h t t p s : / / w w w . h e r o p a t t e r n s . c o m / ) 
 
 
 
 ` ` ` j s 
 
 c o n f i g   =   { 
 
     v a r i a n t s :   [ ] , 
 
     p a t t e r n s :   [ ] , 
 
     c o l o r s :   { 
 
         d e f a u l t :   " 9 C 9 2 A C " 
 
     } , 
 
     o p a c i t y :   { 
 
         d e f a u l t :   0 . 4 
 
     } 
 
 } ; 
 
 ` ` ` 
 
 
 
 # #   P a t t e r n   n a m e s   l i s t : 
 
 1 .   a n c h o r s - a w a y 
 
 1 .   a r c h i t e c t 
 
 1 .   a u t u m n 
 
 1 .   a z t e c 
 
 1 .   b a m b o o 
 
 1 .   b a n k - n o t e 
 
 1 .   b a t h r o o m - f l o o r 
 
 1 .   b e v e l - c i r c l e 
 
 1 .   b o x e s 
 
 1 .   b r i c k - w a l l 
 
 1 .   b u b b l e s 
 
 1 .   c a g e 
 
 1 .   c h a r l i e - b r o w n 
 
 1 .   c h u r c h - o n - s u n d a y 
 
 1 .   c i r c l e s - s q u a r e s 
 
 1 .   c i r c u i t - b o a r d 
 
 1 .   c o n n e c t i o n s 
 
 1 .   c o r k - s c r e w 
 
 1 .   c u r r e n t 
 
 1 .   c u r t a i n 
 
 1 .   c u t o u t 
 
 1 .   d e a t h - s t a r 
 
 1 .   d i a g o n a l - l i n e s 
 
 1 .   d i a g o n a l - s t r i p e s 
 
 1 .   d o m i n o s 
 
 1 .   e n d l e s s - c l o u d s 
 
 1 .   e y e s 
 
 1 .   f a l l i n g - t r i a n g l e s 
 
 1 .   f a n c y - r e c t a n g l e s 
 
 1 .   f l i p p e d - d i a m o n d s 
 
 1 .   f l o a t i n g - c o g s 
 
 1 .   f l o o r - t i l e 
 
 1 .   f o r m a l - i n v i t a t i o n 
 
 1 .   f o u r - p o i n t - s t a r s 
 
 1 .   g l a m o r o u s 
 
 1 .   g r a p h - p a p e r 
 
 1 .   g r o o v y 
 
 1 .   h a p p y - i n t e r s e c t i o n 
 
 1 .   h e a v y - r a i n 
 
 1 .   h e x a g o n s 
 
 1 .   h i d e o u t 
 
 1 .   h o u n d s t o o t h 
 
 1 .   i - l i k e - f o o d 
 
 1 .   i n t e r s e c t i n g - c i r c l e s 
 
 1 .   j i g s a w 
 
 1 .   j u p i t e r 
 
 1 .   k i w i 
 
 1 .   l e a f 
 
 1 .   l i n e s - i n - m o t i o n 
 
 1 .   l i p s 
 
 1 .   l i s b o n 
 
 1 .   m e l t 
 
 1 .   m o r o c c a n 
 
 1 .   m o r p h i n g - d i a m o n d s 
 
 1 .   o v e r c a s t 
 
 1 .   o v e r l a p p i n g - c i r c l e s 
 
 1 .   o v e r l a p p i n g - d i a m o n d s 
 
 1 .   o v e r l a p p i n g - h e x a g o n s 
 
 1 .   p a r k a y - f l o o r 
 
 1 .   p i a n o - m a n 
 
 1 .   p i e - f a c t o r y 
 
 1 .   p i x e l - d o t s 
 
 1 .   p l u s 
 
 1 .   p o l k a - d o t s 
 
 1 .   r a i l s 
 
 1 .   r a i n 
 
 1 .   r a n d o m - s h a p e s 
 
 1 .   r o u n d e d - p l u s - c o n n e c t e d 
 
 1 .   s i g n a l 
 
 1 .   s k u l l s 
 
 1 .   s l a n t e d - s t a r s 
 
 1 .   s q u a r e s 
 
 1 .   s q u a r e s - i n - s q u a r e s 
 
 1 .   s t a m p - c o l l e c t i o n 
 
 1 .   s t e e l - b e a m s 
 
 1 .   s t r i p e s 
 
 1 .   t e m p l e 
 
 1 .   t e x t u r e 
 
 1 .   t i c - t a c - t o e 
 
 1 .   t i n y - c h e c k e r s 
 
 1 .   t o p o g r a p h y 
 
 1 .   v o l c a n o - l a m p 
 
 1 .   w a l l p a p e r 
 
 1 .   w i g g l e 
 
 1 .   x - e q u a l s 
 
 1 .   y y y 
 
 1 .   z i g - z a g 

==> tailwind-heropatterns-0.0.2.tgz: package/README.md <==
#   t a i l w i n d - h e r o p a t t e r n s 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 A d d   t h i s   p l u g i n   t o   y o u r   p r o j e c t : 
 
 
 
 ` ` ` b a s h 
 
 #   I n s t a l l   v i a   n p m 
 
 n p m   i n s t a l l   - - s a v e - d e v   t a i l w i n d - h e r o p a t t e r n s 
 
 
 
 #   o r   y a r n 
 
 y a r n   a d d   t a i l w i n d - h e r o p a t t e r n s   - - d e v 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 
 
 T h e   t a i l w i n d   h e r o p a t t e r n s   p l u g i n   e x p o s e s   s o m e   o p t i o n s   t o   c o n f i g u r e   t h e   g e n e r a t e d   c l a s s e s .   H e r e   i s   t h e   e x a m p l e   f o r   a d d i n g   i t   t o   y o u r   p r o j e c t   p l u g i n s 
 
 
 
 ` ` ` j s 
 
 r e q u i r e ( " t a i l w i n d - h e r o p a t t e r n s " ) ( { 
 
     / /   a s   p e r   t a i l w i n d   d o c s   y o u   c a n   p a s s   v a r i a n t s 
 
     v a r i a n t s :   [ ] , 
 
 
 
     / /   t h e   l i s t   o f   p a t t e r n s   y o u   w a n t   t o   g e n e r a t e   a   c l a s s   f o r 
 
     / /   t h e   n a m e s   m u s t   b e   i n   k e b a b - c a s e   [ s e e   l i s t   i n   r e a d m e ] 
 
     / /   a n   e m p t y   a r r a y   w i l l   g e n e r a t e   a l l   8 7   p a t t e r n s 
 
     p a t t e r n s :   [ " p o l k a - d o t s " ,   " s i g n a l " ] , 
 
 
 
     / /   T h e   f o r e g r o u n d   c o l o r s   o f   t h e   p a t t e r n 
 
     c o l o r s :   { 
 
         d e f a u l t :   " 9 C 9 2 A C " , 
 
         " b l u e - d a r k " :   " 0 0 0 0 4 4 " 
 
     } , 
 
 
 
     / /   T h e   f o r e g r o u n d   o p a c i t y 
 
     o p a c i t i e s :   { 
 
         d e f a u l t :   " 0 . 4 " , 
 
         " 1 0 0 " :   " 1 . 0 " 
 
     } 
 
 } ) ; 
 
 ` ` ` 
 
 
 
 T h i s   c o n f i g u r a t i o n   w o u l d   c r e a t e   t h e   f o l l o w i n g   c l a s s e s : 
 
 
 
 ` ` ` c s s 
 
 . b g - h e r o - p o l k a - d o t s - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - p o l k a - d o t s - b l u e - d a r k - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l - b l u e - d a r k - 1 0 0   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 1 . 0 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - p o l k a - d o t s   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 9 C 9 2 A C '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - p o l k a - d o t s - b l u e - d a r k   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 2 0 '   h e i g h t = ' 2 0 '   v i e w B o x = ' 0   0   2 0   2 0 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C g   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' % 3 E % 3 C c i r c l e   c x = ' 3 '   c y = ' 3 '   r = ' 3 ' / % 3 E % 3 C c i r c l e   c x = ' 1 3 '   c y = ' 1 3 '   r = ' 3 ' / % 3 E % 3 C / g % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 
 
 . b g - h e r o - s i g n a l - b l u e - d a r k   { 
 
     b a c k g r o u n d - i m a g e :   u r l ( " d a t a : i m a g e / s v g + x m l , % 3 C s v g   w i d t h = ' 8 4 '   h e i g h t = ' 4 8 '   v i e w B o x = ' 0   0   8 4   4 8 '   x m l n s = ' h t t p : / / w w w . w 3 . o r g / 2 0 0 0 / s v g ' % 3 E % 3 C p a t h   d = ' . . . '   f i l l = ' % 2 3 0 0 0 0 4 4 '   f i l l - o p a c i t y = ' 0 . 4 '   f i l l - r u l e = ' e v e n o d d ' / % 3 E % 3 C / s v g % 3 E " ) ; 
 
 } 
 
 ` ` ` 
 
 
 
 A s   y o u   c a n   s e e   w h e n   y o u   u s e   t h e   ` d e f a u l t `   k e y   f o r   c o l o r s   o r   o p a c i t y   i t   i s   o m i t t e d   i n   t h e   c l a s s   n a m e . 
 
 
 
 S o   t h e   f o l l o w i n g   c o n f i g u r a t i o n : 
 
 
 
 ` ` ` j s 
 
 r e q u i r e ( " t a i l w i n d - h e r o p a t t e r n s " ) ( { 
 
     v a r i a n t s :   [ ] , 
 
     p a t t e r n s :   [ " p o l k a - d o t s " ,   " s i g n a l " ] , 
 
     c o l o r s :   { 
 
         d e f a u l t :   " 9 C 9 2 A C " 
 
     } , 
 
     o p a c i t i e s :   { 
 
         d e f a u l t :   " 0 . 4 " 
 
     } 
 
 } ) ; 
 
 ` ` ` 
 
 
 
 W i l l   g e n e r a t e   o n l y   t h e   f o l l o w i n g   c l a s s e s 
 
 
 
 ` ` ` c s s 
 
 . b g - h e r o - p o l k a - d o t s   { 
 
     / * * / 
 
 } 
 
 . b g - h e r o - s i g n a l   { 
 
     / * * / 
 
 } 
 
 ` ` ` 
 
 
 
 # #   D e f a u l t s 
 
 
 
 T h e   d e f a u l t   c o n f i g u r a t i o n   i s   t h e   f o l l o w i n g . 
 
 A n d   i t   w i l l   g e n e r a t e   a l l e   t h e   p a t t e r n s   w i t h   t h e   d e f a u l t   c o l o r   o f   [ h e r o p a t t e r n s . c o m ] ( h t t p s : / / w w w . h e r o p a t t e r n s . c o m / ) 
 
 
 
 ` ` ` j s 
 
 c o n f i g   =   { 
 
     v a r i a n t s :   [ ] , 
 
     p a t t e r n s :   [ ] , 
 
     c o l o r s :   { 
 
         d e f a u l t :   " 9 C 9 2 A C " 
 
     } , 
 
     o p a c i t y :   { 
 
         d e f a u l t :   0 . 4 
 
     } 
 
 } ; 
 
 ` ` ` 
 
 
 
 # #   P a t t e r n   n a m e s   l i s t : 
 
 
 
 1 .   a n c h o r s - a w a y 
 
 1 .   a r c h i t e c t 
 
 1 .   a u t u m n 
 
 1 .   a z t e c 
 
 1 .   b a m b o o 
 
 1 .   b a n k - n o t e 
 
 1 .   b a t h r o o m - f l o o r 
 
 1 .   b e v e l - c i r c l e 
 
 1 .   b o x e s 
 
 1 .   b r i c k - w a l l 
 
 1 .   b u b b l e s 
 
 1 .   c a g e 
 
 1 .   c h a r l i e - b r o w n 
 
 1 .   c h u r c h - o n - s u n d a y 
 
 1 .   c i r c l e s - s q u a r e s 
 
 1 .   c i r c u i t - b o a r d 
 
 1 .   c o n n e c t i o n s 
 
 1 .   c o r k - s c r e w 
 
 1 .   c u r r e n t 
 
 1 .   c u r t a i n 
 
 1 .   c u t o u t 
 
 1 .   d e a t h - s t a r 
 
 1 .   d i a g o n a l - l i n e s 
 
 1 .   d i a g o n a l - s t r i p e s 
 
 1 .   d o m i n o s 
 
 1 .   e n d l e s s - c l o u d s 
 
 1 .   e y e s 
 
 1 .   f a l l i n g - t r i a n g l e s 
 
 1 .   f a n c y - r e c t a n g l e s 
 
 1 .   f l i p p e d - d i a m o n d s 
 
 1 .   f l o a t i n g - c o g s 
 
 1 .   f l o o r - t i l e 
 
 1 .   f o r m a l - i n v i t a t i o n 
 
 1 .   f o u r - p o i n t - s t a r s 
 
 1 .   g l a m o r o u s 
 
 1 .   g r a p h - p a p e r 
 
 1 .   g r o o v y 
 
 1 .   h a p p y - i n t e r s e c t i o n 
 
 1 .   h e a v y - r a i n 
 
 1 .   h e x a g o n s 
 
 1 .   h i d e o u t 
 
 1 .   h o u n d s t o o t h 
 
 1 .   i - l i k e - f o o d 
 
 1 .   i n t e r s e c t i n g - c i r c l e s 
 
 1 .   j i g s a w 
 
 1 .   j u p i t e r 
 
 1 .   k i w i 
 
 1 .   l e a f 
 
 1 .   l i n e s - i n - m o t i o n 
 
 1 .   l i p s 
 
 1 .   l i s b o n 
 
 1 .   m e l t 
 
 1 .   m o r o c c a n 
 
 1 .   m o r p h i n g - d i a m o n d s 
 
 1 .   o v e r c a s t 
 
 1 .   o v e r l a p p i n g - c i r c l e s 
 
 1 .   o v e r l a p p i n g - d i a m o n d s 
 
 1 .   o v e r l a p p i n g - h e x a g o n s 
 
 1 .   p a r k a y - f l o o r 
 
 1 .   p i a n o - m a n 
 
 1 .   p i e - f a c t o r y 
 
 1 .   p i x e l - d o t s 
 
 1 .   p l u s 
 
 1 .   p o l k a - d o t s 
 
 1 .   r a i l s 
 
 1 .   r a i n 
 
 1 .   r a n d o m - s h a p e s 
 
 1 .   r o u n d e d - p l u s - c o n n e c t e d 
 
 1 .   s i g n a l 
 
 1 .   s k u l l s 
 
 1 .   s l a n t e d - s t a r s 
 
 1 .   s q u a r e s 
 
 1 .   s q u a r e s - i n - s q u a r e s 
 
 1 .   s t a m p - c o l l e c t i o n 
 
 1 .   s t e e l - b e a m s 
 
 1 .   s t r i p e s 
 
 1 .   t e m p l e 
 
 1 .   t e x t u r e 
 
 1 .   t i c - t a c - t o e 
 
 1 .   t i n y - c h e c k e r s 
 
 1 .   t o p o g r a p h y 
 
 1 .   v o l c a n o - l a m p 
 
 1 .   w a l l p a p e r 
 
 1 .   w i g g l e 
 
 1 .   x - e q u a l s 
 
 1 .   y y y 
 
 1 .   z i g - z a g 
 
 
